FlightElementWaypointMission class

Waypoint Mission.

Inheritance

Constructors

FlightElementWaypointMission({FlightLocation? pointOfInterest, double? maxFlightSpeed = 15.0, double? autoFlightSpeed = 8.0, FlightWaypointMissionFinishedAction? finishedAction = FlightWaypointMissionFinishedAction.noAction, FlightWaypointMissionHeadingMode? headingMode = FlightWaypointMissionHeadingMode.usingWaypointHeading, FlightWaypointMissionPathMode? flightPathMode = FlightWaypointMissionPathMode.curved, bool? rotateGimbalPitch = true, bool? exitMissionOnRCSignalLost = true, required List<FlightWaypoint> waypoints})
FlightElementWaypointMission.fromJson(Map<String, dynamic> json)

Properties

autoFlightSpeed → double?
final
exitMissionOnRCSignalLost → bool?
final
finishedAction → FlightWaypointMissionFinishedAction?
final
flightPathMode → FlightWaypointMissionPathMode?
final
hashCode → int
The hash code for this object.
no setterinherited
headingMode → FlightWaypointMissionHeadingMode?
final
maxFlightSpeed → double?
final
pointOfInterest → FlightLocation?
final
rotateGimbalPitch → bool?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → FlightElementType?
finalinherited
waypoints → List<FlightWaypoint>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited