FlightWaypoint class

Waypoint.

Constructors

FlightWaypoint({required FlightLocation? location, required FlightVector? vector, int? heading = 0, double? cornerRadiusInMeters = 2, FlightWaypointTurnMode? turnMode = FlightWaypointTurnMode.clockwise, double? gimbalPitch})
FlightWaypoint.fromJson(Map<String, dynamic> json)

Properties

cornerRadiusInMeters → double?
final
gimbalPitch ↔ double?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
heading → int?
final
location ↔ FlightLocation?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
turnMode → FlightWaypointTurnMode?
final
vector → FlightVector?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited